@@ -25,6 +25,11 @@ class Catalog(Client):
 
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
 
+        Examples:
+            literal blocks::
+
+                res = Catalog().get_item('ASIN_200', MarketplaceId='TEST_CASE_200')
+
         Args:
             asin: str
             key MarketplaceId: str
@@ -52,6 +57,11 @@ class Catalog(Client):
 
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
 
+        Examples:
+            literal blocks::
+
+                res = Catalog().list_items(MarketplaceId='TEST_CASE_200', SellerSKU='SKU_200')
+
         Args:
             key MarketplaceId: str
             key Query: str
