@@ -31,8 +31,14 @@ class Feeds(Client):
 
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
 
+        Examples:
+            literal blocks::
+
+                Feeds().create_feed('POST_PRODUCT_DATA', '3d4e42b5-1d6e-44e8-a89c-2abfca0625bb',
+                              marketplaceIds=["ATVPDKIKX0DER", "A1F83G8C2ARO7P"])
+
         Args:
-            feed_type: https://github.com/amzn/selling-partner-api-docs/blob/main/references/feeds-api/feedType_string_array_values.md
+            feed_type: https://github.com/amzn/selling-partner-api-docs/blob/main/references/feeds-api/feedtype-values.md
             input_feed_document_id: str
             **kwargs:
 
@@ -131,6 +137,11 @@ class Feeds(Client):
 
         For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
 
+        Examples:
+            literal blocks::
+
+                Feeds().get_feed(feed_id)
+
         Args:
             feed_id: str
             **kwargs:
