@@ -92,3 +92,7 @@ class ReportType(str, Enum):
     RFQD_BULK_DOWNLOAD = 'RFQD_BULK_DOWNLOAD'
     FEE_DISCOUNTS_REPORT = 'FEE_DISCOUNTS_REPORT'
     GET_FLAT_FILE_OFFAMAZONPAYMENTS_SANDBOX_SETTLEMENT_DATA = 'GET_FLAT_FILE_OFFAMAZONPAYMENTS_SANDBOX_SETTLEMENT_DATA'
+    GET_BRAND_ANALYTICS_SEARCH_TERMS_REPORT = 'GET_BRAND_ANALYTICS_SEARCH_TERMS_REPORT'
+    GET_VENDOR_SALES_DIAGNOSTIC_REPORT = 'GET_VENDOR_SALES_DIAGNOSTIC_REPORT'
+    GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT = 'GET_VENDOR_INVENTORY_HEALTH_AND_PLANNING_REPORT'
+    GET_VENDOR_DEMAND_FORECAST_REPORT = 'GET_VENDOR_DEMAND_FORECAST_REPORT'
